@@ -14,7 +14,7 @@
 (*                                                                        *)
 (**************************************************************************)
 
-(* $Id: graphviz.ml,v 1.2 2004/02/23 07:43:53 signoles Exp $ *)
+(* $Id: graphviz.ml,v 1.3 2005/01/18 09:17:49 filliatr Exp $ *)
 
 (** Interface with {i GraphViz}
 
@@ -55,6 +55,10 @@ let fprint_string ppf s =
   then fprintf ppf "%s" s
   else fprintf ppf "\"%s\"" s'
 
+let fprint_string_user ppf s =
+  let s' = String.escaped s in
+    fprintf ppf "\"%s\"" s'
+
 type arrow_style =
   [ `None | `Normal | `Inv | `Dot | `Odot | `Invdot | `Invodot ] 
 
@@ -99,6 +103,9 @@ module CommonAttributes = struct
         (** Traversal order of pages.  Default value is [`TopToBottom]. *)
     | `Size of float * float
         (** Sets the bounding box of drawing (in inches). *)
+    | `OrderingOut
+        (** Constrains  order of out-edges in a subgraph according to
+          their file sequence *)
     ] 
 
   (** Attributes of nodes. *)
@@ -189,11 +196,12 @@ module CommonAttributes = struct
     | `Fontcolor a -> fprintf ppf "fontcolor=%a" fprint_color a
     | `Fontname s -> fprintf ppf "fontname=%a" fprint_string s
     | `Fontsize i -> fprintf ppf "fontsize=%i" i
-    | `Label s -> fprintf ppf "label=%a" fprint_string s
+    | `Label s -> fprintf ppf "label=%a" fprint_string_user s
     | `Orientation a -> fprintf ppf "orientation=%a" fprint_orientation a
     | `Page (x, y) -> fprintf ppf "page=\"%f,%f\"" x y
     | `Pagedir a -> fprintf ppf "pagedir=%a" fprint_dir a
     | `Size (x, y) -> fprintf ppf "size=\"%f,%f\"" x y
+    | `OrderingOut -> fprintf ppf "ordering=out"
 
 
 
@@ -221,7 +229,7 @@ module CommonAttributes = struct
     | `Fontname s -> fprintf ppf "fontname=%a"  fprint_string s
     | `Fontsize i -> fprintf ppf "fontsize=%i" i
     | `Height f -> fprintf ppf "height=%f" f
-    | `Label s -> fprintf ppf "label=%a" fprint_string s
+    | `Label s -> fprintf ppf "label=%a" fprint_string_user s
     | `Orientation f -> fprintf ppf "orientation=%f" f
     | `Peripheries i -> fprintf ppf "peripheries=%i" i
     | `Regular b -> fprintf ppf "regular=%b" b
@@ -247,7 +255,7 @@ module CommonAttributes = struct
     | `Fontcolor a -> fprintf ppf "fontcolor=%a" fprint_color a
     | `Fontname s -> fprintf ppf "fontname=%a" fprint_string s
     | `Fontsize i -> fprintf ppf "fontsize=%i" i
-    | `Label s -> fprintf ppf "label=%a" fprint_string s
+    | `Label s -> fprintf ppf "label=%a" fprint_string_user s
     | `Labelfontcolor a -> fprintf ppf "labelfontcolor=%a" fprint_color a
     | `Labelfontname s -> fprintf ppf "labelfontname=\"%s\"" (String.escaped s)
     | `Labelfontsize i -> fprintf ppf "labelfontsize=%i" i
