@@ -15,7 +15,7 @@
  * (enclosed in the file LGPL).
  *)
 
-(* $Id: pack.ml,v 1.8 2004/11/04 15:39:41 filliatr Exp $ *)
+(* $Id: pack.ml,v 1.12 2005/07/18 07:10:35 filliatr Exp $ *)
 
 module Generic(G : Sig.IA with type V.label = int and type E.label = int) = 
 struct
@@ -80,6 +80,8 @@ struct
 
   include Oper.Make(Builder)
 
+  module PathCheck = Path.Check(G)
+
   module Topological = Topological.Make(G)
 
   module Int = struct
@@ -106,6 +108,41 @@ struct
     if is_directed then Dot.output_graph oc g else Neato.output_graph oc g;
     close_out oc
 
+  let display_with_gv g =
+    let tmp = Filename.temp_file "graph" ".dot" in
+    dot_output g tmp;
+    ignore (Sys.command ("dot -Tps " ^ tmp ^ " | gv -"));
+    Sys.remove tmp
+
+  module GmlParser = 
+    Gml.Parse
+      (Builder)
+      (struct 
+	 let node l = 
+	   try match List.assoc "id" l with Gml.Int n -> n | _ -> -1
+	   with Not_found -> -1
+	 let edge _ =
+	   0
+       end)
+
+  let parse_gml_file = GmlParser.parse
+
+  open Format
+
+  module GmlPrinter =
+    Gml.Print
+      (G)
+      (struct
+	 let node n = ["label", Gml.Int n]
+	 let edge n = ["label", Gml.Int n]
+       end)
+
+  let print_gml_file g f =
+    let c = open_out f in
+    let fmt = formatter_of_out_channel c in
+    fprintf fmt "%a@." GmlPrinter.print g;
+    close_out c
+
 end
 
 module I = struct
@@ -120,3 +157,4 @@ module Digraph = Generic(Imperative.Digraph.AbstractLabeled(I)(I))
 
 module Graph = Generic(Imperative.Graph.AbstractLabeled(I)(I))
 
+
