@@ -15,51 +15,36 @@
  * (enclosed in the file LGPL).
  *)
 
-(* $Id: persistent.mli,v 1.11 2004/11/15 16:42:07 signoles Exp $ *)
+(* $Id: persistent.mli,v 1.12 2004/12/03 09:11:30 signoles Exp $ *)
 
 (** Persistent Implementations *)
 
 open Sig
 
-(** Persistent Directed Graphs *)
-module Digraph : sig
+(** Signature of persistent graphs *)
+module type S = sig
 
-  (** Persistent Directed Unlabeled Graphs *)
+  (** Persistent Unlabeled Graphs *)
   module Concrete (V: COMPARABLE) : 
     Sig.P with type V.t = V.t and type V.label = V.t and type E.t = V.t * V.t
 
-  (** Abstract Persistent Directed Unlabeled Graphs *)
+  (** Abstract Persistent Unlabeled Graphs *)
   module Abstract(V: sig type t end) : Sig.P with type V.label = V.t
 
-  (** Persistent Directed Labeled Graphs *)
+  (** Persistent Labeled Graphs *)
   module ConcreteLabeled (V: COMPARABLE)(E: ORDERED_TYPE_DFT) :
     Sig.P with type V.t = V.t and type V.label = V.t
 	    and type E.t = V.t * E.t * V.t and type E.label = E.t
 
-  (** Abstract Persistent Directed Labeled Graphs *)
+  (** Abstract Persistent Labeled Graphs *)
   module AbstractLabeled (V: sig type t end)(E: ORDERED_TYPE_DFT) :
     Sig.P with type V.label = V.t and type E.label = E.t
 
 end
 
+(** Persistent Directed Graphs *)
+module Digraph : S
+
 (** Persistent Undirected Graphs *)
-module Graph : sig
-
-  (** Persistent Undirected Unlabeled Graphs *)
-  module Concrete (V: COMPARABLE) : 
-    Sig.P with type V.t = V.t and type V.label = V.t and type E.t = V.t * V.t
-
-  (** Abstract Persistent Undirected Unlabeled Graphs *)
-  module Abstract(V: sig type t end) : Sig.P with type V.label = V.t
-
-  (** Persistent Undirected Labeled Graphs *)
-  module ConcreteLabeled (V: COMPARABLE)(E: ORDERED_TYPE_DFT) :
-    Sig.P with type V.t = V.t and type V.label = V.t
-	  and type E.t = V.t * E.t * V.t and type E.label = E.t
-
-  (** Abstract Persistent Undirected Labeled Graphs *)
-  module AbstractLabeled (V: sig type t end)(E: ORDERED_TYPE_DFT) :
-    Sig.P with type V.label = V.t and type E.label = E.t
-
-end
+module Graph : S
 
